@@ -22,6 +22,6 @@ function (x1, x2, theta = rep(1, ncol(x1)), p = 1, C = NA)
         .Fortran("multeb", nd = as.integer(d), x1 = as.double(x1), 
             n1 = as.integer(n1), x2 = as.double(x2), n2 = as.integer(n2), 
             par = as.double(par), c = as.double(C), h = as.double(rep(0, 
-                n1)), work = as.double(rep(0, n2)))$h
+                n1)), work = as.double(rep(0, n2)),PACKAGE="fields")$h
     }
 }
